@@ -129,8 +129,8 @@ $distinputcriteria = "^linux.*\\.deb\$";
 @distributions = ('stable', 'testing', 'unstable');
 
 %distmapping = (
-		stable => 'etch',
-		testing => 'lenny',
+		stable => 'lenny',
+		testing => 'squeeze',
 		unstable => 'sid'
 		);
 
